﻿using System;
using System.Drawing;
using System.Windows.Forms;
using WiseupSoft.Win.Control;

namespace MonthCalendarMSample
{
    ///--------------------------------------------------------------
    /// <summary>
    ///     MonthCalendarM サンプルソースコード</summary>
    /// <history>
    /// <list>Ver.2.0.0.0 2011/04/07 新規作成</list>
    /// <list>Ver.2.0.1.0 2011/04/09 修正     CtrlStyle,TitleStyle,WeekStyle,DayStyle プロパティをデザイン上で変更した場合にその変更箇所が実行時に反映されない不具合を修正しました。</list>
    /// <list>Ver.2.0.2.0 2011/08/27 新規     DoubleClickDate イベントを追加しました。</list>
    /// <list>Ver.2.0.2.0 2011/08/27 新規     SelectedDate プロパティで日付を変更できるようになりました。</list>
    /// <list>Ver.2.0.2.0 2011/08/27 新規     ArgumentOutOfRange イベントを追加しました。最小値から最大値の期間以外の日付が設定された場合に発生します。</list>
    /// <list>Ver.2.0.2.0 2011/08/27 修正     最小値から最大値までの期間以外を選択もしくはキー押下した場合に、例外が発生してしまう不具合を修正しました。</list>
    /// <list>Ver.2.0.3.0 2012/04/02 修正     カレンダーデータの生成に不具合があったので修正しました。</list>
    /// <list>Ver.2.0.3.0 2012/09/16 修正     未使用プロパティを隠匿するように修正しました。</list>
    /// <list>Ver.2.1.0.0 2013/05/16 修正     月を移動した際に移動前のツールチップが残ってしまっていた不具合を修正しました。</list>
    /// <list>Ver.2.1.0.0 2013/05/23 修正     コントロールパネル-地球-日付の設定でカレンダーの種類を和暦にした場合に例外が発生する不具合を修正しました。</list>
    /// <list>Ver.2.1.0.0 2013/05/25 新規     カスタム日付の設定機能を追加しました。</list>
    /// <list>Ver.2.1.0.1 2013/08/06 修正     休日設定ファイルが反映されない不具合を修正しました。</list>
    /// <list>Ver.2.1.0.1 2013/08/06 修正     現在年月と異なる場合において、タイトルバーをクリックしても現在日付へ移動できない不具合を修正しました。</list>
    /// <list>Ver.2.1.0.1 2013/08/06 仕様変更 現在月以外の日をクリックした場合において、選択日の月に移動するように仕様を変更しました。</list>
    /// <list>Ver.2.1.0.1 2013/08/06 仕様変更 現在月以外の日をクリックした場合において、選択日の月に移動するように仕様を変更しました。</list>
    /// <list>Ver.2.1.0.2 2016/05/27 新規     指定した日付に関連付けられているカスタム日付情報を取得する TryGetValue メソッドを追加しました。</list>
    /// <list>Ver.2.1.0.2 2016/05/27 新規     指定した日付がカスタムデータに登録されているか確認する ContainsKey メソッドを追加しました。</list>
    /// <list>Ver.2.1.0.2 2016/05/27 新規     カスタム日付データすべての削除が正常に完了した場合に発生する CustomDateClearCompleted イベントを追加しました。</list>
    /// <list>Ver.2.1.0.2 2016/05/27 新規     カスタム日付データの削除が正常に完了した場合に発生する CustomDateRemoveCompleted イベントを追加しました。</list>
    /// <list>Ver.2.1.0.2 2016/05/27 修正     最後のカスタム日付データを削除しても背景色、及び文字色が規定値に戻らない場合がある不具合を修正しました。</list>
    /// <list>Ver.2.1.0.2 2016/06/06 仕様変更 カスタム日付設定レコード数が０件の場合においてもファイルを保存（作成）するように仕様を変更しました。</list>
    /// <list>Ver.2.1.0.3 2016/06/11 新規     TitleStyle プロパティに表示月の高さを設定する Height プロパティを追加しました。</list>
    /// <list>Ver.2.1.0.3 2016/06/11 新規     TitleStyle プロパティに次月への移動を表すイメージを設定する NextMonthImage プロパティを追加しました。</list>
    /// <list>Ver.2.1.0.3 2016/06/11 新規     TitleStyle プロパティに前月への移動を表すイメージを設定する PreviousMonthImage プロパティを追加しました。</list>
    /// <list>Ver.2.1.0.3 2016/06/11 仕様変更 TitleStyle プロパティの Font プロパティの規定値を ＭＳ ゴシック から Meiryo UI に変更しました。</list>
    /// <list>Ver.2.1.0.3 2016/06/11 仕様変更 WeekStyle プロパティの Font プロパティの規定値を ＭＳ ゴシック から Meiryo UI に変更しました。</list>
    /// <list>Ver.2.1.0.4 2016/06/15 新規     ActiveDayStyle プロパティを追加しました。</list>
    /// <list>Ver.2.1.0.5 2016/09/22 修正     タイトルバー([表示年月])押下、または[Ctrl+T]キー押下において、現在日がMaxDate プロパティの設定値よりも以前の場合、例外KeyNotFoundExceptionが発生してしまう不具合を修正しました。</list>
    /// <list>Ver.2.1.0.5 2016/09/22 新規     タイトルバー([表示年月])押下、または[Ctrl+T]キー押下において、現在日に移動するかしないかを決定する ThisDateMove プロパティを追加しました。</list>
    /// <list>Ver.2.1.0.5 2016/09/22 仕様変更 現在日よりも以前の日付に MaxDate プロパティ値を変更した場合、MaxDate プロパティの設定値にフォーカスを移動させるように仕様を変更しました。</list>
    /// <list>Ver.2.1.0.5 2016/10/06 修正     前月および次月ボタン押下において、MinDate、MaxDate プロパティの設定値より小さい、または大きい場合にカレンダーを再生成していた不具合を修正しました。</list>
    /// <list>Ver.2.1.0.5 2016/12/16 修正     現在月以外にカレンダーを移動した場合、選択日を初期化するように修正しました。</list>
    /// <list>Ver.2.1.0.5 2016/12/16 修正     カレンダーに表示されている翌月の日付をクリックすると例外が発生する不具合を修正しました。</list>
    /// <list>Ver.2.1.0.6 2016/12/21 仕様変更 [前月]および[次月]ボタンを押した場合に、日付を選択するかどうかを設定する MonthMoveActiveDate プロパティを追加しました。</list>
    /// </history>
    public partial class Form1 : Form
    {
        #region コンストラクタ & Form_Load

        public Form1()
        {
            InitializeComponent();
           
            this.settingDate.ValueChanged　+=　settingDate_ValueChanged;
            this.MinDate.ValueChanged += MinDate_ValueChanged;
            this.MaxDate.ValueChanged += MaxDate_ValueChanged;
            this.MultiSelectOff.CheckedChanged += MultiSelect_CheckedChanged;
            this.MultiSelectOn.CheckedChanged += MultiSelect_CheckedChanged;
            this.cmbStartOfWeek.SelectedIndexChanged += cmbStartOfWeek_SelectedIndexChanged;
            this.MonthCalendarM.SelectedDateChanged += MonthCalendarM_SelectedDateChanged;
            
            this.MonthCalendarM.ClickDate += MonthCalendarM_ClickDate;
            this.MonthCalendarM.DoubleClickDate += MonthCalendarM_DoubleClickDate;
            this.MonthCalendarM.EnterKeyClick += MonthCalendarM_EnterKeyClick;
            this.MonthCalendarM.MultiDateSelected += MonthCalendarM_MultiDateSelected;
            this.MonthCalendarM.ArgumentOutOfRange += MonthCalendarM_ArgumentOutOfRange;
            // Ver.2.1.0.0 で追加
            this.MonthCalendarM.CustomDateAddCompleted += MonthCalendarM_CustomDateAddCompleted;
            this.MonthCalendarM.CustomDateSaveCompleted += MonthCalendarM_CustomDateSaveCompleted;
            this.MonthCalendarM.CustomDateReadCompleted += MonthCalendarM_CustomDateReadCompleted;
            // Ver.2.1.0.2 で追加
            this.MonthCalendarM.CustomDateClearCompleted += MonthCalendarM1_CustomDateClearCompleted;
            this.MonthCalendarM.CustomDateRemoveCompleted += MonthCalendarM1_CustomDateRemoveCompleted;
            // Ver.2.1.0.4 で追加
            this.cmbActiveBorderStyle.SelectedIndex = 0;
            lblActiveDayStyle_BorderColor.BackColor = Color.Blue;
            lblActiveDayStyle_GradationStartColor.BackColor = Color.PowderBlue;
            lblActiveDayStyle_GradationEndColor.BackColor = Color.White;
            // Ver.2.1.0.5 で追加
            this.rdoThisDateMoveOn.CheckedChanged += rdoThisDateMove_CheckedChanged;
            this.rdoThisDateMoveOff.CheckedChanged += rdoThisDateMove_CheckedChanged;
        }

        private void Form_Load(object sender, EventArgs e)
        {
            this.cmbStartOfWeek.SelectedIndex = 0;
            //this.MonthCalendarM.SelectedDate = new DateTime(DateTime.Today.Year, DateTime.Today.Month, DateTime.Today.Day);
            this.lblStart.Text = this.MonthCalendarM.SelectedDate.ToString("yyyy/MM/dd");
        }

        #endregion

        #region 【Ver.2.0.0】～ 【Ver.2.0.3】

        ///--------------------------------------------------------------
        /// <summary>
        ///     カレンダーコントロールの日付を変更します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void settingDate_ValueChanged(object sender, EventArgs e)
        {
            // 設定方法１ (SetDate メソッドで指定する）
            //this.MonthCalendarM1.SetDate(this.DateTimePicker1.Value);

            // 設定方法２（SelectedDate プロパティで指定する）
            this.MonthCalendarM.SelectedDate = this.settingDate.Value;
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     許容される日付の最小値が変更された場合に発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MinDate_ValueChanged(object sender, EventArgs e)
        {
            this.MonthCalendarM.MinDate = this.MinDate.Value;
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     許容される日付の最大値が変更された場合に発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MaxDate_ValueChanged(object sender, EventArgs e)
        {
            this.MonthCalendarM.MaxDate = this.MaxDate.Value;
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     カレンダーの複数選択値が変更された場合に発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MultiSelect_CheckedChanged(Object sender, EventArgs e)
        {
            if (this.MultiSelectOff.Checked)
            {
                this.MonthCalendarM.MultiSelect = MultiSelect.None;
                this.MultiSelMsgLabel.Visible = false;
            }
            else
            {
                this.MonthCalendarM.MultiSelect = MultiSelect.Simple;
                this.MultiSelMsgLabel.Visible = true;
            }
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     カレンダーの最初の列に表示する曜日が変更された場合に発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void cmbStartOfWeek_SelectedIndexChanged(Object sender, EventArgs e)
        {
            this.MonthCalendarM.StartOfWeek = (StartOfWeek)this.cmbStartOfWeek.SelectedIndex;
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     日付がクリックされたときに発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MonthCalendarM_ClickDate(Object sender, ClickDateEventArgs e)
        {
            this.lblStart.Text = e.Date.ToString("yyyy/MM/dd");
            this.lblMsg.Text = null;
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     日付がダブルクリックされたときに発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MonthCalendarM_DoubleClickDate(Object sender, EventArgs e)
        {
            MessageBox.Show(string.Format("日付がダブルクリックされました。選択日:{0}", this.MonthCalendarM.SelectedDate.ToString("yyyy/MM/dd")));
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     [Enter]キーが押下されたときに発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MonthCalendarM_EnterKeyClick(Object sender, EventArgs e)
        {
            MessageBox.Show("[Enter]キーが押下されました。");
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     ユーザーがマウスを使用して明示的に複数の日付を選択した場合に発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MonthCalendarM_MultiDateSelected(Object sender, WiseupSoft.Win.Control.DateRangeEventArgs e)
        {
            this.lblStart.Text = e.Start.ToString("yyyy/MM/dd");
            this.lblEnd.Text = e.End.ToString("yyyy/MM/dd");
            this.lblMsg.Text = null;
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     最小値から最大値以外の日付が設定された場合に発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        public void MonthCalendarM_ArgumentOutOfRange(Object sender, EventArgs e)
        {
            this.lblMsg.Text = "最小値から最大値以外の日付が設定されました。";
        }

        #endregion

        #region 【Ver.2.1.0.0】からの新機能 指定する日付の背景色、文字色、ツールチップを設定する機能を追加しました。

        /********************************************************************************
         * バージョンアップ直後は、CustomDate.xml は存在しませんのでご注意ください。
         * まずはカスタム日付の設定を行い、ファイルの保存を行ってください。
         ********************************************************************************/

        #region カスタム日付設定ファイル読み込み処理
        ///--------------------------------------------------------------
        /// <summary>
        ///     カスタム日付設定ファイル(CustomDate.xml)を読み込んで設定します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void btnCustomFileRead_Click(object sender, EventArgs e)
        {
            try
            {
                // 設定ファイル(CustomDate.xml)の規定値での配置場所は、MonthCalendarM.dll と同じ場所になります。
                this.MonthCalendarM.CustomDateFileRead();

                //// 任意の場所に設定ファイルが配置されている場合は、下記のようにパスを設定してください。
                //this.MonthCalendarM1.CustomDateFileRead("カスタム日付設定ファイル(CustomDate.xml)のパス");

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     非同期でカスタム日付設定ファイル(CustomDate.xml)を読み込んで設定します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void btnCustomFileReadAsync_Click(object sender, EventArgs e)
        {
            try
            {
                // 設定ファイル(CustomDate.xml)の規定値での配置場所は、MonthCalendarM.dll と同じ場所になります。
                this.MonthCalendarM.CustomDateFileReadAsync(this);

                // 任意の場所に設定ファイルが配置されている場合は、下記のようにパスを設定してください。
                //this.MonthCalendarM1.CustomDateFileReadAsync(this, "カスタム日付設定ファイル(CustomDate.xml)のパス");

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     カスタム日付設定ファイルの読込みに成功した場合に発生するイベントです。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MonthCalendarM_CustomDateReadCompleted(object sender, CustomDateReadCompletedEventArgs e)
        {
            try
            {
                this.lblCustomDateMessage.Text = string.Format("カスタム日付設定ファイル[{0} の読込みが完了しました...", e.ReadFile);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        #endregion

        #region カスタム日付の登録処理

        ///--------------------------------------------------------------
        /// <summary>
        ///     カスタム日付の追加および設定を行います。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void btnCustomDateAppend_Click(object sender, EventArgs e)
        {
            try
            {
                // 設定方法１(単一）
                this.MonthCalendarM.CustomDateAdd(new CustomDate(new DateTime(DateTime.Now.Year, DateTime.Now.Month, 5), Color.Blue, Color.White, "特別な日"));

                // 設定方法2（複数）
                this.MonthCalendarM.CustomDateAdd(
                    new CustomDate(new DateTime(DateTime.Now.Year, DateTime.Now.Month, 23), Color.Red, Color.White, "休暇"),
                    new CustomDate(new DateTime(DateTime.Now.Year, DateTime.Now.Month, 24), Color.Red, Color.White, "休暇"),
                    new CustomDate(new DateTime(DateTime.Now.Year, DateTime.Now.Month, 10), Color.Red, Color.White, "カスタム日付上書き"),
                    new CustomDate(new DateTime(DateTime.Now.Year, DateTime.Now.Month, 17), Color.Red, Color.White, "カスタム日付上書き"));

                // 設定方法３(単一）
                CustomDate cd = new CustomDate();
                cd.TargetDate = new DateTime(DateTime.Now.Year, DateTime.Now.Month, 15);
                cd.BackColor = Color.Blue;
                cd.ForeColor = Color.White;
                cd.ToolTip = "誕生日";
                this.MonthCalendarM.CustomDateAdd(cd);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     カスタム日付を追加します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void btnCdAdd_Click(object sender, EventArgs e)
        {
            try
            {
                this.MonthCalendarM.CustomDateAdd(
                    new CustomDate(cdTargetDate.Value, this.cdBackColor.BackColor, this.cdForeColor.BackColor, this.cdToolTip.Text));

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     背景色の選択処理</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void cdBackColorBtn_Click(object sender, EventArgs e)
        {
            try
            {
                using (ColorDialog cd = new ColorDialog())
                {
                    cd.Color = this.cdBackColor.BackColor;
                    if (cd.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                        this.cdBackColor.BackColor = cd.Color;
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     文字色の選択処理</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void cdForeColorBtn_Click(object sender, EventArgs e)
        {
            try
            {
                using (ColorDialog cd = new ColorDialog())
                {
                    cd.Color = this.cdForeColor.BackColor;
                    if (cd.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                        this.cdForeColor.BackColor = cd.Color;
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     カスタム日付が登録された場合に発生するイベントです。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MonthCalendarM_CustomDateAddCompleted(Object sender, CustomDateAddEventArgs e)
        {
            try
            {
                this.lblCustomDateMessage.Text = string.Format("カスタム日付が登録されました。{0}", e.Value.TargetDate.ToString("yyyy/MM/dd"));
                // 登録済データを取得します。
                btnCustomDateView_Click(sender, EventArgs.Empty);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        #endregion

        #region カスタム日付設定ファイル保存処理

        ///--------------------------------------------------------------
        /// <summary>
        ///     カスタム日付設定ファイルを保存します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void btnCustomDateSave_Click(object sender, EventArgs e)
        {
            try
            {
                // 設定ファイル(CustomDate.xml)の規定値での保存場所は、MonthCalendarM.dll と同じ場所になります。
                this.MonthCalendarM.CustomDateFileSave();

                // 任意の場所に設定ファイルを保存する場合は、下記のようにパスを設定してください。
                //this.MonthCalendarM1.CustomDateFileSave("カスタム日付設定ファイル(CustomDate.xml)のパス");

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     カスタム日付設定ファイルの保存に成功した場合に発生するイベントです。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MonthCalendarM_CustomDateSaveCompleted(Object sender, CustomDateSaveCompletedEventArgs e)
        {
            this.lblCustomDateMessage.Text = string.Format("カスタム日付設定ファイル[{0} の保存が完了しました...", e.SaveFile);
            // 登録済データを取得します。
            btnCustomDateView_Click(sender, EventArgs.Empty);
        }

        #endregion

        ///--------------------------------------------------------------
        /// <summary>
        ///     登録済カスタム日付データを取得します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void btnCustomDateView_Click(object sender, EventArgs e)
        {
            try
            {
                this.dataGridView1.DataSource = this.MonthCalendarM.CustomDate;

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

#endregion

        #region 【Ver.2.1.0.2】で追加または修正された機能について

        ///--------------------------------------------------------------
        /// <summary>
        ///     直前に選択されていた日付とは異なる日付が選択されたときに発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MonthCalendarM_SelectedDateChanged(Object sender, EventArgs e)
        {
            this.lblStart.Text = this.MonthCalendarM.SelectedDate.ToString("yyyy/MM/dd");
            this.cdTargetDate.Value = this.MonthCalendarM.SelectedDate;
            this.lblEnd.Text = null;
            this.lblMsg.Text = null;
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     カスタム日付データを初期化します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void btnCustomDataDel_Click(object sender, EventArgs e)
        {
            try
            {
                this.MonthCalendarM.CustomDateClear();
                // Ver.2.1.0.2から CustomDateClearCompletedイベントを新規に追加しましたので不要となりました。
                ////// 登録済データを取得します。
                //////btnCustomDateView_Click(sender, EventArgs.Empty);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     グリッドで選択中のカスタム日付を削除します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void btnCdDel_Click(object sender, EventArgs e)
        {
            try
            {
                // グリッドから選択されている日付を取得します。
                DateTime targetDate = (DateTime)dataGridView1.SelectedCells[0].Value;

                // 指定した日付がカスタム日付情報に登録されているか確認を行い、登録されていれば削除します。
                if (this.MonthCalendarM.ContainsKey(targetDate))
                {
                    this.MonthCalendarM.CustomDateRemove(targetDate);
                }

                //(参考）TryGetValue メソッドでも同様の確認が可能です。
                //CustomDate cd = new CustomDate();
                //if (this.MonthCalendarM1.TryGetValue(targetDate, out cd))
                //{
                //    lblRemoveDate.Text = cd.TargetDate.ToString("yyyy/MM/dd");
                //}
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     カスタム日付データの削除が正常に完了した場合に発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MonthCalendarM1_CustomDateRemoveCompleted(object sender, CustomDateRemoveEventArgs e)
        {
            lblCustomDateMessage.Text = string.Format("カスタム日付データ {0} が削除されました...", e.Value.ToString("yyyy/MM/dd"));
            // 登録済データを取得します。
            btnCustomDateView_Click(sender, EventArgs.Empty);
        }

        ///--------------------------------------------------------------
        /// <summary>
        ///     カスタム日付データすべての削除が正常に完了した場合に発生します。</summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        ///--------------------------------------------------------------
        private void MonthCalendarM1_CustomDateClearCompleted(object sender, EventArgs e)
        {
            lblCustomDateMessage.Text = "カスタム日付データすべての削除が正常に完了しました...";
            // 登録済データを取得します。
            btnCustomDateView_Click(sender, EventArgs.Empty);
        }

        /// <summary>
        /// カスタム日付データのレコード数変更検知イベント
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void dataGridView1_DataSourceChanged(object sender, EventArgs e)
        {
            try
            {
                object ret = dataGridView1.Rows.Count > 0 ? btnCdDel.Enabled = true : btnCdDel.Enabled = false;   
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        #endregion

        #region 【Ver.2.1.0.4】で追加または修正された機能について

        /// <summary>
        /// アクティブ日付の境界線スタイルを変更した場合に発生するイベント
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void cmbActiveBorderStyle_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (cmbActiveBorderStyle.SelectedIndex == 0)
            {
                // アクティブ日付の境界線スタイルが「外周を四角形で描画」の場合
                MonthCalendarM.ActiveDayStyle.BorderStyle = ActiveBorderStyle.Border;
                GroupBox7.Enabled = true;
                GroupBox8.Enabled = false;
            }
            else
            {
                // アクティブ日付の境界線スタイルが「グラデーションで描画」の場合
                MonthCalendarM.ActiveDayStyle.BorderStyle = ActiveBorderStyle.Gradation;
                GroupBox7.Enabled = false;
                GroupBox8.Enabled = true;
            }
        }

        /// <summary>
        /// アクティブ日付の境界線スタイルが「外周を四角形で描画」の場合に枠線の色を設定します。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Button1_Click(object sender, EventArgs e)
        {
            try
            {
                using (ColorDialog cd = new ColorDialog())
                {
                    cd.Color = lblActiveDayStyle_BorderColor.BackColor;
                    if (cd.ShowDialog() == DialogResult.OK)
                    {
                        lblActiveDayStyle_BorderColor.BackColor = cd.Color;
                        // 旧型式です。
                        MonthCalendarM.CtrlStyle.ActiveBorder = cd.Color;
                        // 下記の記述方法に変更をお願いいたします。
                        MonthCalendarM.ActiveDayStyle.BorderColor = cd.Color;
                    }
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// アクティブ日付の境界線スタイルが「グラデーションで描画」の場合、開始色を設定します。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Button2_Click(object sender, EventArgs e)
        {
            try
            {
                using (ColorDialog cd = new ColorDialog())
                {
                    cd.Color = lblActiveDayStyle_GradationStartColor.BackColor;
                    if (cd.ShowDialog() == DialogResult.OK)
                    {
                        lblActiveDayStyle_GradationStartColor.BackColor = cd.Color;
                        MonthCalendarM.ActiveDayStyle.GradationStartColor = cd.Color;
                    }
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// アクティブ日付の境界線スタイルが「グラデーションで描画」の場合、終了色を設定します。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Button3_Click(object sender, EventArgs e)
        {
            try
            {
                using (ColorDialog cd = new ColorDialog())
                {
                    cd.Color = lblActiveDayStyle_GradationEndColor.BackColor;
                    if (cd.ShowDialog() == DialogResult.OK)
                    {
                        lblActiveDayStyle_GradationEndColor.BackColor = cd.Color;
                        MonthCalendarM.ActiveDayStyle.GradationEndColor = cd.Color;
                    }
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        #endregion

        #region 【Ver.2.1.0.5】で追加された機能について

        /// <summary>
        ///     タイトルバー([表示年月])押下時のイベント
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void rdoThisDateMove_CheckedChanged(object sender, EventArgs e)
        {
            if (this.rdoThisDateMoveOn.Checked)
            {
                // 現在日(システム日付)への移動を許可します。
                this.MonthCalendarM.ThisDateMove = true;
            }
            else
            {
                // 現在日(システム日付)への移動を許可しません。
                this.MonthCalendarM.ThisDateMove = false;
            }
        }

        #endregion

        #region 【Ver.2.1.0.6】で追加された機能について

        private void rdoMonthMoveActiveDate_CheckedChanged(object sender, EventArgs e)
        {
            if (this.rdoMonthMoveActiveDateOn.Checked)
            {
                // [前月]および[次月]ボタンを押した場合に、日付を選択します。
                this.MonthCalendarM.MonthMoveActiveDate = true;
            }
            else
            {
                // [前月]および[次月]ボタンを押した場合に、日付を選択しません。
                this.MonthCalendarM.MonthMoveActiveDate = false;
            }
        }

        #endregion
    }
}
